summaryrefslogtreecommitdiff
path: root/src/rebar_erlc_compiler.erl
diff options
context:
space:
mode:
Diffstat (limited to 'src/rebar_erlc_compiler.erl')
-rw-r--r--src/rebar_erlc_compiler.erl6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/rebar_erlc_compiler.erl b/src/rebar_erlc_compiler.erl
index 376cde5..f628433 100644
--- a/src/rebar_erlc_compiler.erl
+++ b/src/rebar_erlc_compiler.erl
@@ -48,10 +48,10 @@
}).
-ifdef(namespaced_types).
-% digraph:digraph() exists starting from Erlang 17.
--type rebar_digraph() :: digraph:digraph().
+%% digraph:graph() exists starting from Erlang 17.
+-type rebar_digraph() :: digraph:graph().
-else.
-% digraph() has been obsoleted in Erlang 17 and deprecated in 18.
+%% digraph() has been obsoleted in Erlang 17 and deprecated in 18.
-type rebar_digraph() :: digraph().
-endif.